<?php

namespace Drupal\recurly_aegir\Processors;

use Drupal\node\Entity\Node;
use Drupal\recurly_aegir\Provisioners\SiteDeleteProvisioner;

/**
 * {@inheritdoc}
 *
 * Process expired subscriptions.
 */
class SubscriptionExpiredProcessor extends Processor {

  /**
   * {@inheritdoc}
   *
   * Delete sites associated with this subscription.
   */
  public function process() {
    if (!$this->subscription->isExpired()) {
      return $this->failAndLogMessage("Subscription %uuid for user %user has not expired; cannot process.");
    }

    $user_id = $this->subscription->getUserId($this->getAccountCode(), TRUE);

    foreach (array_values($this->subscription->getSiteIds($user_id)) as $site_id) {
      $site = Node::load($site_id);
      $provisioner = new SiteDeleteProvisioner($site);
      $provisioner->performActionAndLogResults();
      $site->save();
    }

    $this->result = TRUE;
    return $this;
  }

}
