<?php

namespace Drupal\recurly_aegir\Provisioners;

/**
 * Fetches the list of profiles via Aegir's Web service API.
 */
class ProfileListProvisioner extends Provisioner {

  /**
   * The activity that was performed by this provisioner's execution.
   */
  const ACTION_PERFORMED = 'Profiles listed';

  /**
   * {@inheritdoc}
   *
   * Returns the list of allowed profiles.
   */
  protected function provision() {
    $this->sendRequestAndReceiveResponse('profile.json', []);
    return $this;
  }

  /**
   * {@inheritdoc}
   *
   * @return array
   *   The list of query string parameters
   */
  protected function getQueryParametersToSend() {
    return ['machine_names' => 1];
  }

  /**
   * Fetch the list of profiles and return it.
   *
   * @param bool $cacheable
   *   Boolean indicating if the results are cacheable.
   *
   * @return array
   *   The list of profiles.
   */
  public static function getProfileList($cacheable) {
    $provisioner = new static();
    $profiles = $provisioner->performActionAndLogResults()->getResponse();
    return $profiles;
  }

  /**
   * {@inheritdoc}
   */
  protected function recordSuccessLogMessage() {
    $this->getLogger()
      ->info('Remote hosting system: Successfully returned list of site installation profiles via %provisioner.', [
        '%provisioner' => $this->getClassName(),
      ]);
    return $this;
  }

}
