<?php

namespace Drupal\recurly_aegir\Provisioners;

/**
 * Class for installing new sites via Aegir's Web service API.
 */
class SiteInstallProvisioner extends SiteCreateProvisioner {

  /**
   * The remote site task being executed by this provisioner.
   */
  const TASK_TYPE = 'install';

  /**
   * The activity that was performed by this provisioner's execution.
   */
  const ACTION_PERFORMED = 'Site installed';

  /**
   * {@inheritdoc}
   *
   * Provisions new sites via install tasks.
   */
  protected function provision() {
    $this->sendRequestAndReceiveResponse('task', [
      // Task type.
      'type' => $this->getTaskType(),
      // New site name.
      'target' => $this->getSiteName(),
      'options' => [
        // Installation profile.
        'profile' => $this->template,
        // Client username.
        'client_name' => $this->getClient()->getDisplayName(),
        // Client e-mail address.
        'client_email' => $this->getClient()->getEmail(),
      ],
    ]);

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  protected function recordSuccessLogMessage() {
    $this->getLogger()
      ->info('Remote site %sitename: Task %task created to provision site for %client from %template via %provisioner.', [
        '%sitename' => $this->getSiteName(),
        '%task' => $this->getTaskId(),
        '%client' => $this->getClient()->getDisplayName(),
        '%template' => $this->getTemplate(),
        '%provisioner' => $this->getClassName(),
      ]);
    return $this;
  }

  /**
   * {@inheritdoc}
   *
   * Report status and next steps for subscribers of new sites.
   */
  public function performActionAndLogResults() {
    parent::performActionAndLogResults();

    try {
      if ($this->getTaskId()) {
        drupal_set_message(t('Your new site %site is in the process of being provisioned. This usually takes several minutes. When complete, you will receive an e-mail with instructions for logging into it.', [
          '%site' => $this->getSiteName(),
        ]));
      }
    }
    catch (TaskCreationFailedException $e) {
      watchdog_exception('recurly_aegir', $e);
    }

    return $this;
  }

}
