<?php

namespace Drupal\recurly_aegir\Provisioners;

/**
 * Fetches the list of sites via Aegir's Web service API.
 */
class SiteListProvisioner extends Provisioner {

  /**
   * The activity that was performed by this provisioner's execution.
   */
  const ACTION_PERFORMED = 'Sites listed';

  /**
   * {@inheritdoc}
   *
   * Returns the list of existing sites.
   */
  protected function provision() {
    $this->sendRequestAndReceiveResponse('site.json', []);
    return $this;
  }

  /**
   * Fetch the list of sites and return it.
   *
   * @return array
   *   The list of sites.
   */
  public static function getSiteList() {
    $provisioner = new static();
    $sites = $provisioner->performActionAndLogResults()->getResponse();
    return $sites;
  }

  /**
   * {@inheritdoc}
   */
  protected function recordSuccessLogMessage() {
    $this->getLogger()
      ->info('Remote hosting system: Successfully returned list of sites via %provisioner.', [
        '%provisioner' => $this->getClassName(),
      ]);
    return $this;
  }

}
