<?php

namespace Drupal\recurly_aegir\Provisioners;

use Drupal\node\Entity\Node;
use Drupal\recurly_aegir\Exceptions\TaskCreationFailedException;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class for provisioning site requests via Aegir's Web service API.
 */
abstract class SiteProvisioner extends Provisioner {

  /**
   * The site to provision.
   *
   * @var Drupal\node\Entity\Node
   */
  protected $site;

  /**
   * Class Constructor.
   *
   * @param Drupal\node\Entity\Node $site
   *   The site to provision.
   */
  public function __construct(Node $site) {
    if (empty($site)) {
      throw new \Exception('Site provisioners must be provided with a site node on construction.');
    }

    $this->site = $site;
  }

  /**
   * Returns the name of the site.
   */
  public function getSiteName() {
    return $this->site->getTitle() . '.' . \Drupal::request()->getHost();
  }

  /**
   * {@inheritdoc}
   *
   * Log the action to the site node as well as the general system log.
   */
  public function performActionAndLogResults() {
    try {
      parent::performActionAndLogResults()->logActionToSite();
    }
    catch (TaskCreationFailedException $e) {
      watchdog_exception('recurly_aegir', $e);
    }
    return $this;
  }

  /**
   * Log the action and associated details to the site node.
   */
  protected function logActionToSite() {
    $aegir_url = Request::create($this->getAegirServiceEndpoint())->getSchemeAndHttpHost();

    $this->site->field_site_tasks->appendItem([
      'uri' => $aegir_url . $this->getRemoteTargetPath(),
      'title' => date("Y-m-d \@ H:i:s") . ' » ' . $this->getActionPerformed(),
    ]);

    return $this;
  }

  /**
   * Returns the path of the remote object being acted upon.
   */
  protected function getRemoteTargetPath() {
    return '/hosting/c/' . $this->getRemoteTargetId();
  }

  /**
   * Returns the ID of the remote object being acted upon.
   */
  protected function getRemoteTargetId() {
    return $this->getSiteName();
  }

}
