<?php

namespace Drupal\recurly_aegir\Provisioners;

/**
 * Class for verifying sites via Aegir's Web service API.
 */
class SiteVerifyProvisioner extends SiteProvisioner {
  use TaskProvisioningTrait;

  /**
   * The remote site task being executed by this provisioner.
   */
  const TASK_TYPE = 'verify';

  /**
   * The activity that was performed by this provisioner's execution.
   */
  const ACTION_PERFORMED = 'Site verified';

  /**
   * {@inheritdoc}
   *
   * Verifies a site.
   */
  protected function provision() {
    $this->sendRequestAndReceiveResponse('task', [
      'type' => $this->getTaskType(),
      'target' => $this->getSiteName(),
    ]);

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  protected function recordSuccessLogMessage() {
    $this->getLogger()
      ->info('Remote site %sitename: Task %task created to verify it via %provisioner.', [
        '%sitename' => $this->getSiteName(),
        '%task' => $this->getTaskId(),
        '%provisioner' => $this->getClassName(),
      ]);
    return $this;
  }

}
